//	Collidable.h - Base class for any collidable actors.
//  ----------------------------------------------------------------------------
//	This file is part of 'NiallsAVLib', base code for any kind of audiovisual
//	apps.
//	Copyright (C) 2012  Niall Moody
//	
//	This program is free software: you can redistribute it and/or modify
//	it under the terms of the GNU General Public License as published by
//	the Free Software Foundation, either version 3 of the License, or
//	(at your option) any later version.
//
//	This program is distributed in the hope that it will be useful,
//	but WITHOUT ANY WARRANTY; without even the implied warranty of
//	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//	GNU General Public License for more details.
//
//	You should have received a copy of the GNU General Public License
//	along with this program.  If not, see <http://www.gnu.org/licenses/>.
//	----------------------------------------------------------------------------

#ifndef COLLIDABLE_H_
#define COLLIDABLE_H_

#include "TwoFloats.h"

#include <string>

///	Base class for any collidable actors.
class Collidable
{
  public:
	///	Destructor.
	virtual ~Collidable() {};

	///	Returns the actor's collision radius.
	virtual float getRadius() const = 0;
	///	Returns the actor's position.
	virtual const TwoFloats& getPosition() const = 0;

	///	Returns the actor's type name.
	virtual const std::wstring getName() const = 0;
	///	Called when the actor has collided with another.
	virtual void collided(const std::wstring& other,
						  const TwoFloats& otherPos) = 0;
	///	Returns true if this actor should not be counted in collisions.
	virtual bool doNotCount() const = 0;
};

#endif
