//	EnemyBullet.cpp - The enemy bullet class.
//  ----------------------------------------------------------------------------
//	This file is part of 'NiallsAVLib', base code for any kind of audiovisual
//	apps.
//	Copyright (C) 2012  Niall Moody
//	
//	This program is free software: you can redistribute it and/or modify
//	it under the terms of the GNU General Public License as published by
//	the Free Software Foundation, either version 3 of the License, or
//	(at your option) any later version.
//
//	This program is distributed in the hope that it will be useful,
//	but WITHOUT ANY WARRANTY; without even the implied warranty of
//	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//	GNU General Public License for more details.
//
//	You should have received a copy of the GNU General Public License
//	along with this program.  If not, see <http://www.gnu.org/licenses/>.
//	----------------------------------------------------------------------------

#include "drawing/Drawer.h"
#include "EnemyBullet.h"

//------------------------------------------------------------------------------
EnemyBullet::EnemyBullet(const TwoFloats& pos, const TwoFloats& dir):
position(pos),
direction(dir),
dead(false)
{
	
}

//------------------------------------------------------------------------------
EnemyBullet::EnemyBullet(const EnemyBullet& other):
position(other.position),
direction(other.direction),
dead(false)
{

}

//------------------------------------------------------------------------------
EnemyBullet::~EnemyBullet()
{

}

//------------------------------------------------------------------------------
bool EnemyBullet::update()
{
	bool retval = false;

	position += direction * 12.0f;

	if((position.x < -64.0f) ||
	   (position.x > 1600.0f) ||
	   (position.y < -64.0f) ||
	   (position.y > 1600.0f))
	{
		retval = true;
	}

	return retval;
}

//------------------------------------------------------------------------------
void EnemyBullet::draw(shared_ptr<Drawer >& d)
{
	const TwoFloats origin;
	float angle;

	angle = -direction.getAngle(origin);

	d->drawRotImage(L"EnemyBullet",
					position-8.0f,
					angle,
					TwoFloats(8.0f, 12.0f));
}

//------------------------------------------------------------------------------
void EnemyBullet::collided(const std::wstring& other,
							const TwoFloats& otherPos)
{
	if(other == L"Player")
	{
		dead = true;
	}
}

//------------------------------------------------------------------------------
float EnemyBullet::getAngle() const
{
	TwoFloats origin;

	return origin.getAngle(direction);
}
