//	EventDisplay.cpp - Used to display Cut!, Copy! etc. text.
//  ----------------------------------------------------------------------------
//	This file is part of 'NiallsAVLib', base code for any kind of audiovisual
//	apps.
//	Copyright (C) 2012  Niall Moody
//	
//	This program is free software: you can redistribute it and/or modify
//	it under the terms of the GNU General Public License as published by
//	the Free Software Foundation, either version 3 of the License, or
//	(at your option) any later version.
//
//	This program is distributed in the hope that it will be useful,
//	but WITHOUT ANY WARRANTY; without even the implied warranty of
//	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//	GNU General Public License for more details.
//
//	You should have received a copy of the GNU General Public License
//	along with this program.  If not, see <http://www.gnu.org/licenses/>.
//	----------------------------------------------------------------------------

#include "drawing/Drawer.h"
#include "EventDisplay.h"

//------------------------------------------------------------------------------
EventDisplay::EventDisplay():
size(0.0f),
sizeTweener(size, 0.0f, 0.02f),
alpha(0.0f),
alphaTweener(alpha, 0.0f, 0.04f),
displayOn(false)
{

}

//------------------------------------------------------------------------------
EventDisplay::~EventDisplay()
{

}

//------------------------------------------------------------------------------
void EventDisplay::draw(shared_ptr<Drawer>& d)
{
	if(displayOn)
	{
		TwoFloats tempPos;

		if(!sizeTweener.getFinished())
			sizeTweener.tick();
		if(!alphaTweener.getFinished())
			alphaTweener.tick();
		else if((alpha > 0.5f) && (image != L"GameOver"))
			alphaTweener.reset(0.0f);
		else if(image != L"GameOver")
			displayOn = false;

		tempPos = d->getDrawingAreaSize() * 0.5f;
		tempPos -= (d->getInternalImageData(image)->size * 0.5f) * size;

		d->drawImage(image, tempPos, size, ThreeFloats(1.0f), alpha);
	}
}

//------------------------------------------------------------------------------
void EventDisplay::trigger(const std::wstring& im)
{
	image = im;

	size = 0.0f;
	sizeTweener.setIndex(0.0f);
	sizeTweener.reset(1.0f);

	alpha = 0.0f;
	/*if(image == L"GameOver")
		alphaTweener.setDelta(0.02f);*/
	alphaTweener.setIndex(0.0f);
	alphaTweener.reset(1.0f);

	displayOn = true;
}
