//	EventDisplay.h - Used to display Cut!, Copy! etc. text.
//  ----------------------------------------------------------------------------
//	This file is part of 'NiallsAVLib', base code for any kind of audiovisual
//	apps.
//	Copyright (C) 2012  Niall Moody
//	
//	This program is free software: you can redistribute it and/or modify
//	it under the terms of the GNU General Public License as published by
//	the Free Software Foundation, either version 3 of the License, or
//	(at your option) any later version.
//
//	This program is distributed in the hope that it will be useful,
//	but WITHOUT ANY WARRANTY; without even the implied warranty of
//	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//	GNU General Public License for more details.
//
//	You should have received a copy of the GNU General Public License
//	along with this program.  If not, see <http://www.gnu.org/licenses/>.
//	----------------------------------------------------------------------------

#ifndef EVENTDISPLAY_H_
#define EVENTDISPLAY_H_

#include "c0xHeaders.h"
#include "TwoFloats.h"
#include "Tweener.h"

#include <string>

class Drawer;

///	Used to display Cut!, Copy! etc. text.
class EventDisplay
{
  public:
	///	Constructor.
	EventDisplay();
	///	Destructor.
	~EventDisplay();

	///	Draws the display.
	void draw(shared_ptr<Drawer>& d);

	///	Triggers the display.
	void trigger(const std::wstring& im);
  private:
	///	The display's image.
	std::wstring image;
	///	The display's size.
	TwoFloats size;
	///	The display's size tweener.
	Tweener<TwoFloats> sizeTweener;
	///	The display's alpha.
	float alpha;
	///	The display's alpha tweener.
	STweener<float> alphaTweener;

	///	Whether or not the display is actually displaying.
	bool displayOn;
};

#endif
