//	Mine.cpp - The basic Mine class.
//  ----------------------------------------------------------------------------
//	This file is part of 'NiallsAVLib', base code for any kind of audiovisual
//	apps.
//	Copyright (C) 2012  Niall Moody
//	
//	This program is free software: you can redistribute it and/or modify
//	it under the terms of the GNU General Public License as published by
//	the Free Software Foundation, either version 3 of the License, or
//	(at your option) any later version.
//
//	This program is distributed in the hope that it will be useful,
//	but WITHOUT ANY WARRANTY; without even the implied warranty of
//	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//	GNU General Public License for more details.
//
//	You should have received a copy of the GNU General Public License
//	along with this program.  If not, see <http://www.gnu.org/licenses/>.
//	----------------------------------------------------------------------------

#include "drawing/Drawer.h"
#include "ColourHelpers.h"
#include "Random.h"
#include "Mine.h"
#include "Shard.h"

//------------------------------------------------------------------------------
Mine::Mine(const TwoFloats& pos):
position(pos),
fadeIn(0.0f),
dead(false),
blue(false)
{
	ThreeFloats hslCol;

	hslCol.x = Random::getGlobal().getRandomFloat();
	hslCol.y = 0.75f;
	hslCol.z = 0.75f;
	shards.push_back(shared_ptr<Shard>(new Shard(L"MineTri0",
									   ColourHelpers::hslToRgb(hslCol),//ThreeFloats(146.0f/255.0f, 1.0f, 175.0f/255.0f),
									   TwoFloats(20.0f, 35.0f))));
	shards.back()->setPosition(position-32.0f);
	hslCol.x += (1.0f/6.0f);
	if(hslCol.x > 1.0f)
		hslCol.x -= 1.0f;
	shards.push_back(shared_ptr<Shard>(new Shard(L"MineTri1",
												 ColourHelpers::hslToRgb(hslCol),//ThreeFloats(1.0f, 1.0f, 146.0f/255.0f),
												 TwoFloats(18.0f, 16.0f))));
	shards.back()->setPosition(position-32.0f);
	hslCol.x += (1.0f/6.0f);
	if(hslCol.x > 1.0f)
		hslCol.x -= 1.0f;
	shards.push_back(shared_ptr<Shard>(new Shard(L"MineTri2",
												 ColourHelpers::hslToRgb(hslCol),//ThreeFloats(146.0f/255.0f, 1.0f, 224.0f/255.0f),
												 TwoFloats(11.0f, 28.0f))));
	shards.back()->setPosition(position-32.0f);
	hslCol.x += (1.0f/6.0f);
	if(hslCol.x > 1.0f)
		hslCol.x -= 1.0f;
	shards.push_back(shared_ptr<Shard>(new Shard(L"MineTri3",
												 ColourHelpers::hslToRgb(hslCol),//ThreeFloats(146.0f/255.0f, 147.0f/255.0f, 1.0f),
												 TwoFloats(19.0f, 20.0f))));
	shards.back()->setPosition(position-32.0f);
	hslCol.x += (1.0f/7.0f);
	if(hslCol.x > 1.0f)
		hslCol.x -= 1.0f;
	shards.push_back(shared_ptr<Shard>(new Shard(L"MineTri4",
												 ColourHelpers::hslToRgb(hslCol),//ThreeFloats(1.0f, 146.0f/255.0f, 146.0f/255.0f),
												 TwoFloats(26.0f, 17.0f))));
	shards.back()->setPosition(position-32.0f);
	hslCol.x += (1.0f/7.0f);
	if(hslCol.x > 1.0f)
		hslCol.x -= 1.0f;
	shards.push_back(shared_ptr<Shard>(new Shard(L"MineTri5",
												 ColourHelpers::hslToRgb(hslCol),//ThreeFloats(1.0f, 146.0f/255.0f, 146.0f/255.0f),
												 TwoFloats(18.0f, 33.0f))));
	shards.back()->setPosition(position-32.0f);
}

//------------------------------------------------------------------------------
Mine::Mine(const Mine& other):
position(other.position),
fadeIn(0.0f),
dead(false)
{
	unsigned int i;
	const std::vector<shared_ptr<Shard> >& otherShards = other.getShards();

	for(i=0;i<otherShards.size();++i)
		shards.push_back(shared_ptr<Shard>(new Shard(*(otherShards[i]))));
}

//------------------------------------------------------------------------------
Mine::~Mine()
{
	unsigned int i;

	for(i=0;i<shards.size();++i)
		shards[i]->setDirection((shards[i]->getPosition() - position).normal());
}

//------------------------------------------------------------------------------
void Mine::draw(shared_ptr<Drawer>& d)
{
	if((position > TwoFloats(-64.0f)) &&
	   (position < (d->getDrawingAreaSize()+64.0f)))
	{
		unsigned int i;

		for(i=0;i<shards.size();++i)
			shards[i]->draw(d, fadeIn);
	}

	if(fadeIn < 1.0f)
	{
		fadeIn += 0.01f;
		if(fadeIn > 1.0f)
			fadeIn = 1.0f;
	}
}

//------------------------------------------------------------------------------
void Mine::collided(const std::wstring& other, const TwoFloats& otherPos)
{
	if((other == L"Player") || (other == L"Enemy"))
		dead = true;
}

//------------------------------------------------------------------------------
void Mine::incPosition(const TwoFloats& pos)
{
	unsigned int i;

	position += pos;

	for(i=0;i<shards.size();++i)
		shards[i]->setPosition(position-32.0f);
}

//------------------------------------------------------------------------------
void Mine::setFlash()
{
	unsigned int i;

	for(i=0;i<shards.size();++i)
		shards[i]->setFlash();
}

//------------------------------------------------------------------------------
void Mine::setBlue()
{
	unsigned int i;

	for(i=0;i<shards.size();++i)
		shards[i]->setBlue();

	blue = true;
}

//------------------------------------------------------------------------------
void Mine::setDead()
{
	dead = true;
}
