//	Mine.h - The basic Mine class.
//  ----------------------------------------------------------------------------
//	This file is part of 'NiallsAVLib', base code for any kind of audiovisual
//	apps.
//	Copyright (C) 2012  Niall Moody
//	
//	This program is free software: you can redistribute it and/or modify
//	it under the terms of the GNU General Public License as published by
//	the Free Software Foundation, either version 3 of the License, or
//	(at your option) any later version.
//
//	This program is distributed in the hope that it will be useful,
//	but WITHOUT ANY WARRANTY; without even the implied warranty of
//	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//	GNU General Public License for more details.
//
//	You should have received a copy of the GNU General Public License
//	along with this program.  If not, see <http://www.gnu.org/licenses/>.
//	----------------------------------------------------------------------------

#ifndef MINE_H_
#define MINE_H_

#include "c0xHeaders.h"
#include "Collidable.h"

#include <vector>

class Drawer;
class Shard;

///	The basic Mine class.
class Mine : public Collidable
{
  public:
	///	Constructor,
	Mine(const TwoFloats& pos);
	///	Copy Constructor.
	Mine(const Mine& other);
	///	Destructor.
	~Mine();

	///	Draws the Mine.
	void draw(shared_ptr<Drawer>& d);

	///	Returns the Mine's position.
	const TwoFloats& getPosition() const {return position;};
	///	The Mine's radius.
	float getRadius() const {return 20.0f;};
	///	The Mine's type name for collision purposes.
	const std::wstring getName() const {return L"Mine";};
	///	Called when the Mine collides with another actor.
	void collided(const std::wstring& other, const TwoFloats& otherPos);
	///	Returns true while the Mine is fading in.
	bool doNotCount() const {return fadeIn < 1.0f;};

	///	Used to set the Mine's starting position on paste.
	void incPosition(const TwoFloats& pos);

	///	Flashes the Mine when it's been copied.
	void setFlash();
	///	Marks the Mine as selected.
	void setBlue();
	///	Kills the Mine.
	void setDead();

	///	Returns true if the Mine is selected.
	bool getBlue() const {return blue;};
	///	Returns true if the Mine is dead.
	bool getDead() const {return dead;};
	///	Returns the vector of this Mine's shards.
	const std::vector<shared_ptr<Shard> >& getShards() const {return shards;};
  private:
	///	The Mine's current position.
	TwoFloats position;

	///	The Mine's shards.
	std::vector<shared_ptr<Shard> > shards;

	///	Used to fade the Mine in at it's birth.
	float fadeIn;
	///	Whether or not the Mine is dead.
	bool dead;
	///	True if the Mine is selected.
	bool blue;
};

#endif
