//	Pickup.cpp - The pickup class.
//  ----------------------------------------------------------------------------
//	This file is part of 'NiallsAVLib', base code for any kind of audiovisual
//	apps.
//	Copyright (C) 2012  Niall Moody
//	
//	This program is free software: you can redistribute it and/or modify
//	it under the terms of the GNU General Public License as published by
//	the Free Software Foundation, either version 3 of the License, or
//	(at your option) any later version.
//
//	This program is distributed in the hope that it will be useful,
//	but WITHOUT ANY WARRANTY; without even the implied warranty of
//	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//	GNU General Public License for more details.
//
//	You should have received a copy of the GNU General Public License
//	along with this program.  If not, see <http://www.gnu.org/licenses/>.
//	----------------------------------------------------------------------------

#include "drawing/Drawer.h"
#include "MiscHelper.h"
#include "Pickup.h"
#include "Random.h"

//------------------------------------------------------------------------------
Pickup::Pickup(const TwoFloats& pos):
position(pos),
dead(false),
angle(0.0f)
{
	pickup = Random::getGlobal().getRandomInt(3);
	if(pickup > 2)
		pickup = 2;
}

//------------------------------------------------------------------------------
Pickup::~Pickup()
{

}

//------------------------------------------------------------------------------
void Pickup::draw(shared_ptr<Drawer>& d)
{
	TwoFloats tempPos(position);

	switch(pickup)
	{
		case 0:
			tempPos.x -= 38.0f*0.5f * 0.5f;
			tempPos.y -= 50.0f*0.5f * 0.5f;
			d->drawImage(L"PickupClipboard", tempPos, TwoFloats(0.5f));
			break;
		case 1:
			tempPos.x -= 43.0f*0.5f * 0.5f;
			tempPos.y -= 38.0f*0.5f * 0.5f;
			d->drawImage(L"PickupUndo", tempPos, TwoFloats(0.5f));
			break;
		case 2:
			tempPos.x -= 46.0f*0.5f * 0.5f;
			tempPos.y -= 49.0f*0.5f * 0.5f;
			d->drawImage(L"PickupSelectAll", tempPos, TwoFloats(0.5f));
			break;
	}

	d->drawRotImage(L"PickupRing",
					position-(56.0f*0.5f),
					angle,
					TwoFloats((57.0f*0.5f), (56.0f*0.5f)));
	angle += 0.01f;
	if(angle > (2.0f * NIALL_PI))
		angle -= (2.0f * NIALL_PI);
}

//------------------------------------------------------------------------------
void Pickup::collided(const std::wstring& other, const TwoFloats& otherPos)
{
	if(other == L"Player")
		dead = true;
}
