//	Pickup.h - The pickup class.
//  ----------------------------------------------------------------------------
//	This file is part of 'NiallsAVLib', base code for any kind of audiovisual
//	apps.
//	Copyright (C) 2012  Niall Moody
//	
//	This program is free software: you can redistribute it and/or modify
//	it under the terms of the GNU General Public License as published by
//	the Free Software Foundation, either version 3 of the License, or
//	(at your option) any later version.
//
//	This program is distributed in the hope that it will be useful,
//	but WITHOUT ANY WARRANTY; without even the implied warranty of
//	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//	GNU General Public License for more details.
//
//	You should have received a copy of the GNU General Public License
//	along with this program.  If not, see <http://www.gnu.org/licenses/>.
//	----------------------------------------------------------------------------

#ifndef PICKUP_H_
#define PICKUP_H_

#include "c0xHeaders.h"
#include "Collidable.h"
#include "TwoFloats.h"

class Drawer;

///	The pickup class.
class Pickup : public Collidable
{
  public:
	///	Constructor.
	Pickup(const TwoFloats& pos);
	///	Destructor.
	~Pickup();

	///	Draws the pickup.
	void draw(shared_ptr<Drawer>& d);

	///	Which pickup this is.
	int getPickup() const {return pickup;};
	///	Returns true if the pickup should be deleted.
	bool getDead() const {return dead;};

	///	Returns the actor's collision radius.
	float getRadius() const {return 32.0f;};
	///	Returns the actor's position.
	const TwoFloats& getPosition() const {return position;};

	///	Returns the actor's type name.
	const std::wstring getName() const {return L"Pickup";};
	///	Called when the actor has collided with another.
	void collided(const std::wstring& other, const TwoFloats& otherPos);
	///	Returns true if this actor should not be counted in collisions.
	bool doNotCount() const {return false;};
  private:
	///	Which pickup this is.
	int pickup;
	///	The pickup's position.
	TwoFloats position;
	///	True if the pickup should be deleted.
	bool dead;

	///	Used to rotate the spinning circle around the pickup.
	float angle;
};

#endif
