//	Player.cpp - The player class.
//  ----------------------------------------------------------------------------
//	This file is part of 'NiallsAVLib', base code for any kind of audiovisual
//	apps.
//	Copyright (C) 2012  Niall Moody
//	
//	This program is free software: you can redistribute it and/or modify
//	it under the terms of the GNU General Public License as published by
//	the Free Software Foundation, either version 3 of the License, or
//	(at your option) any later version.
//
//	This program is distributed in the hope that it will be useful,
//	but WITHOUT ANY WARRANTY; without even the implied warranty of
//	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//	GNU General Public License for more details.
//
//	You should have received a copy of the GNU General Public License
//	along with this program.  If not, see <http://www.gnu.org/licenses/>.
//	----------------------------------------------------------------------------

#include "drawing/Drawer.h"
#include "ColourHelpers.h"
#include "Random.h"
#include "Player.h"
#include "Shard.h"

//------------------------------------------------------------------------------
Player::Player():
position(640.0f, 360.0f),
desiredPosition(640.0f, 360.0f),
direction(0.0f, -1.0f),
dead(false)
{
	ThreeFloats hslCol;

	hslCol.x = Random::getGlobal().getRandomFloat();
	hslCol.y = 0.75f;
	hslCol.z = 0.75f;
	shards.push_back(shared_ptr<Shard>(new Shard(L"PlayerTri0",
									   ColourHelpers::hslToRgb(hslCol),//ThreeFloats(145.0f/255.0f, 183.0f/255.0f, 239.0f/255.0f),
									   TwoFloats(18.0f, 19.0f))));
	hslCol.x += (1.0f/6.0f);
	if(hslCol.x > 1.0f)
		hslCol.x -= 1.0f;
	shards.back()->setPosition(position-32.0f);
	shards.push_back(shared_ptr<Shard>(new Shard(L"PlayerTri1",
									   ColourHelpers::hslToRgb(hslCol),//ThreeFloats(239.0f/255.0f, 237.0f/255.0f, 142.0f/255.0f),
									   TwoFloats(20.0f, 11.0f))));
	hslCol.x += (1.0f/6.0f);
	if(hslCol.x > 1.0f)
		hslCol.x -= 1.0f;
	shards.back()->setPosition(position-32.0f);
	shards.push_back(shared_ptr<Shard>(new Shard(L"PlayerTri2",
									   ColourHelpers::hslToRgb(hslCol),//ThreeFloats(239.0f/255.0f, 143.0f/255.0f, 143.0f/255.0f),
									   TwoFloats(15.0f, 13.0f))));
	hslCol.x += (1.0f/6.0f);
	if(hslCol.x > 1.0f)
		hslCol.x -= 1.0f;
	shards.back()->setPosition(position-32.0f);
	shards.push_back(shared_ptr<Shard>(new Shard(L"PlayerTri3",
									   ColourHelpers::hslToRgb(hslCol),//ThreeFloats(145.0f/255.0f, 162.0f/255.0f, 239.0f/255.0f),
									   TwoFloats(29.0f, 17.0f))));
	hslCol.x += (1.0f/6.0f);
	if(hslCol.x > 1.0f)
		hslCol.x -= 1.0f;
	shards.back()->setPosition(position-32.0f);
}

//------------------------------------------------------------------------------
Player::~Player()
{
	unsigned int i;

	for(i=0;i<shards.size();++i)
		shards[i]->setDirection((shards[i]->getPosition() - position).normal());
}

//------------------------------------------------------------------------------
void Player::update()
{
	unsigned int i;
	TwoFloats lastPos;

	if(position != desiredPosition)
	{
		lastPos = position;
		position += (desiredPosition-position) * 0.1f;
		if(position.getDistance(desiredPosition) < 1.0f)
			position = desiredPosition;

		direction = (position-lastPos).normal();

		for(i=0;i<shards.size();++i)
			shards[i]->setPosition(position-32.0f);
	}
}

//------------------------------------------------------------------------------
void Player::draw(shared_ptr<Drawer>& d)
{
	unsigned int i;

	for(i=0;i<shards.size();++i)
		shards[i]->draw(d);
}

//------------------------------------------------------------------------------
void Player::mouseMove(const TwoFloats& pos)
{
	desiredPosition = pos;
}

//------------------------------------------------------------------------------
void Player::collided(const std::wstring& other, const TwoFloats& otherPos)
{
	unsigned int i;

	if(!dead && ((other == L"Enemy") ||
				 (other == L"Mine") ||
				 (other == L"EnemyBullet")))
	{
		dead = true;

		for(i=0;i<shards.size();++i)
			shards[i]->setDirection((shards[i]->getPosition() - position).normal());
	}
}
