//	Player.h - The player class.
//  ----------------------------------------------------------------------------
//	This file is part of 'NiallsAVLib', base code for any kind of audiovisual
//	apps.
//	Copyright (C) 2012  Niall Moody
//	
//	This program is free software: you can redistribute it and/or modify
//	it under the terms of the GNU General Public License as published by
//	the Free Software Foundation, either version 3 of the License, or
//	(at your option) any later version.
//
//	This program is distributed in the hope that it will be useful,
//	but WITHOUT ANY WARRANTY; without even the implied warranty of
//	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//	GNU General Public License for more details.
//
//	You should have received a copy of the GNU General Public License
//	along with this program.  If not, see <http://www.gnu.org/licenses/>.
//	----------------------------------------------------------------------------

#ifndef PLAYER_H_
#define PLAYER_H_

#include "c0xHeaders.h"
#include "Collidable.h"

class Drawer;
class Shard;

///	The player class.
class Player : public Collidable
{
  public:
	///	Constructor.
	Player();
	///	Destructor.
	~Player();

	///	Moves the player.
	void update();
	///	Draws the player.
	void draw(shared_ptr<Drawer>& d);

	///	Used to move the player.
	void mouseMove(const TwoFloats& pos);

	///	Returns the player's position.
	const TwoFloats& getPosition() const {return position;};
	///	Returns the player's direction.
	const TwoFloats& getDirection() const {return direction;};

	///	The player's radius.
	float getRadius() const {return 24.0f;};
	///	The player's type name for collision purposes.
	const std::wstring getName() const {return L"Player";};
	///	Which other actors the player will collide with.
	void collided(const std::wstring& other, const TwoFloats& otherPos);
	///	Returns true always.
	bool doNotCount() const {return false;};

	///	Returns true if the player's dead.
	bool getDead() const {return dead;};
	///	Returns the vector of this enemy's shards.
	const std::vector<shared_ptr<Shard> >& getShards() const {return shards;};
  private:
	///	The player's current position.
	TwoFloats position;
	///	The player's desired position.
	TwoFloats desiredPosition;

	///	The player's current direction.
	TwoFloats direction;

	///	The player's shards.
	std::vector<shared_ptr<Shard> > shards;

	///	True if the player's dead.
	bool dead;
};

#endif
