//	PlayerBullet.h - The player bullet class.
//  ----------------------------------------------------------------------------
//	This file is part of 'NiallsAVLib', base code for any kind of audiovisual
//	apps.
//	Copyright (C) 2012  Niall Moody
//	
//	This program is free software: you can redistribute it and/or modify
//	it under the terms of the GNU General Public License as published by
//	the Free Software Foundation, either version 3 of the License, or
//	(at your option) any later version.
//
//	This program is distributed in the hope that it will be useful,
//	but WITHOUT ANY WARRANTY; without even the implied warranty of
//	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//	GNU General Public License for more details.
//
//	You should have received a copy of the GNU General Public License
//	along with this program.  If not, see <http://www.gnu.org/licenses/>.
//	----------------------------------------------------------------------------

#ifndef PLAYERBULLET_H_
#define PLAYERBULLET_H_

#include "c0xHeaders.h"
#include "Collidable.h"

class Drawer;

///	The player bullet class.
class PlayerBullet : public Collidable
{
  public:
	///	Constructor.
	PlayerBullet(const TwoFloats& pos, const TwoFloats& dir);
	///	Copy constructor.
	PlayerBullet(const PlayerBullet& other);
	///	Destructor.
	~PlayerBullet();

	///	Moves the bullet.
	/*!
		\return True if the bullet is outside the screen.
	 */
	bool update();
	///	Draws the bullet.
	void draw(shared_ptr<Drawer >& d);

	///	///	Returns the bullet's position.
	const TwoFloats& getPosition() const {return position;};
	///	The bullet's radius.
	float getRadius() const {return 20.0f;};
	///	The bullet's type name for collision purposes.
	const std::wstring getName() const {return L"PlayerBullet";};
	///	Which other actors the bullet will collide with.
	void collided(const std::wstring& other, const TwoFloats& otherPos);
	///	Returns true always.
	bool doNotCount() const {return false;};

	///	Returns the bullet's angle.
	float getAngle() const;

	///	Returns true if the bullet's dead.
	bool getDead() const {return dead;};
  private:
	///	The bullet's position.
	TwoFloats position;
	///	The bullet's direction.
	TwoFloats direction;

	///	Whether or not the bullet's dead.
	bool dead;
};

#endif
