//	TitleScreen.h - The title screen state.
//  ----------------------------------------------------------------------------
//	This file is part of 'NiallsAVLib', base code for any kind of audiovisual
//	apps.
//	Copyright (C) 2012  Niall Moody
//	
//	This program is free software: you can redistribute it and/or modify
//	it under the terms of the GNU General Public License as published by
//	the Free Software Foundation, either version 3 of the License, or
//	(at your option) any later version.
//
//	This program is distributed in the hope that it will be useful,
//	but WITHOUT ANY WARRANTY; without even the implied warranty of
//	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//	GNU General Public License for more details.
//
//	You should have received a copy of the GNU General Public License
//	along with this program.  If not, see <http://www.gnu.org/licenses/>.
//	----------------------------------------------------------------------------

#ifndef TITLESCREEN_H_
#define TITLESCREEN_H_

#include "drawing/TextLayout.h"
#include "ThreeFloats.h"
#include "GameState.h"
#include "Tweener.h"

class PastarenaGlobalData;

///	The title screen state.
class TitleScreen : public GameState
{
  public:
	///	Constructor.
	TitleScreen(Application& app, SounderPtr sound);
	///	Destructor.
	~TitleScreen();

	///	Draws the state.
	void draw(DrawerPtr d);

	///	Called when a key down event is received.
	void keyDown(const std::wstring& action,
				 const std::wstring& keyPressed,
				 int keyModifier);

	///	Used to restart when the player dies.
	void mouseDown(int button, const TwoFloats& pos);

	///	Returns the name of this state.
	const std::wstring getName() const {return L"TitleScreen";};
	///	Used to construct instances of this state.
	static GameStateCreator<TitleScreen> creator;
  private:
	///	Helper method. Calculates a reasonable background colour.
	ThreeFloats getBackColour();

	///	Positions of the two background textures.
	TwoFloats backPos[2];
	///	Tweener for the first background texture.
	STweener<TwoFloats> backTween0;
	///	Tweener for the second background texture.
	STweener<TwoFloats> backTween1;

	///	Sizes of the two background textures.
	TwoFloats(backSize[2]);
	///	Tweener for the firstfirst background texture.
	STweener<TwoFloats> backSizeTween0;
	///	Tweener for the second background texture.
	STweener<TwoFloats> backSizeTween1;

	///	The background colour.
	ThreeFloats backColour;
	///	The tweener for the background colour.
	STweener<ThreeFloats> backColTween;

	///	The two TextLayouts.
	TextLayout textLayouts[3];

	///	Used to fade in at the start.
	float fadeIn;

	///	Our global data.
	shared_ptr<PastarenaGlobalData> globalData;
};

#endif
