//	CrashSynth.cpp - The crash synthesizer.
//  ----------------------------------------------------------------------------
//	This file is part of 'GameTemplate', template code for a game.
//	Copyright (C) 2010  Niall Moody
//	
//	This program is free software: you can redistribute it and/or modify
//	it under the terms of the GNU General Public License as published by
//	the Free Software Foundation, either version 3 of the License, or
//	(at your option) any later version.
//
//	This program is distributed in the hope that it will be useful,
//	but WITHOUT ANY WARRANTY; without even the implied warranty of
//	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//	GNU General Public License for more details.
//
//	You should have received a copy of the GNU General Public License
//	along with this program.  If not, see <http://www.gnu.org/licenses/>.
//	----------------------------------------------------------------------------

#include "CrashSynth.h"
#include "MiscHelper.h"
#include "Random.h"

#include <cmath>

//------------------------------------------------------------------------------
CrashSynth::CrashSynth():
active(false),
start(0),
length(0.0f),
increment(3.0f/44100.0f),
filter(0.0f),
filterCoeff(0.99f),
feedback(0.8f),
delayWrite(0),
//delayRead(0),
delayLength(0.1f)
{
	int i;

	for(i=0;i<DelaySize;++i)
		delay[i] = 0.0f;
}

//------------------------------------------------------------------------------
CrashSynth::~CrashSynth()
{
	
}

//------------------------------------------------------------------------------
void CrashSynth::getAudio(float *buffer, int numSamples)
{
	int i;
	float l;
	int tempint, tempint2;
	float tempf, tempf2;

	for(i=start;i<numSamples;++i)
	{
		//Count down the sound's timer.
		length -= increment;
		if(length <= 0.0f)
		{
			setActive(false, 0, false);
			break;
		}

		l = length;
		if(filterCoeff == 0.9f)
			l = length/1.5f;

		//Generate the audio.

		//Calculate filtered noise.
		tempf2 = Random::getGlobal().getRandomFloat();
		tempf = (tempf2 - (filter * filterCoeff));
		filter = tempf2;

		//Calculate delay.
		tempint = (int)((float)delayWrite - delayLength);
		if(tempint < 0)
			tempint += DelaySize;
		tempint2 = tempint + 1;
		if(tempint2 >= DelaySize)
			tempint2 = 0;
		tempf2 = delayLength - (float)((int)delayLength);
		tempf2 = (delay[tempint] * (1.0f-tempf2)) + (delay[tempint2] * tempf2);
		delay[delayWrite] = tempf + (tempf2 * feedback);
		tempf2 = tempf * 1.0f;
		tempf2 += (delay[delayWrite] * 1.0f) * fakeLog(1.0f-l);
		++delayWrite;
		if(delayWrite >= DelaySize)
			delayWrite = 0;

		buffer[i*2] += tempf2 * fakeExp(l) * 0.33f;
		buffer[(i*2)+1] += tempf2 * fakeExp(l) * 0.33f;
	}
	start = 0;
}

//------------------------------------------------------------------------------
void CrashSynth::setActive(bool val, int startSample, bool hi)
{
	active = val;
	if(active)
	{
		start = startSample;

		length = 1.0f;

		if(hi)
		{
			filterCoeff = 0.999f;
			length = 1.0f;
		}
		else
		{
			filterCoeff = 0.9f;
			length = 1.5f;
		}
	}
}
